package suicideChess;

/**
 * This class is used for square representation
 * 
 * @author Jean-Baptiste H&eacute;tier
 * @version $LastChangedRevision$, $LastChangedDate$
 */


public class Square {
	private char file;
	private int fileNb;
	private int rank;

	public class NotAValidSquare extends Exception {
		/**
		 * Generated by Eclipse
		 */
		private static final long serialVersionUID = 7586171991212094565L;

		NotAValidSquare(String s) { super(s); };
	}
	
	/**
	 * Construcs a Square given a String ("a1", "b7", "g5", ...)
	 * @param square A string representing the Square. 
	 */
	
	public Square(String square) throws NotAValidSquare {
		if (square.length()!=2 || !(Character.isLetter(square.toCharArray()[0])) || 
				!(Character.isDigit(square.toCharArray()[1]))) {
			throw new NotAValidSquare(square);	
		}
		file = Character.toLowerCase(square.toCharArray()[0]);
		fileNb = ((int)file) - ((int)'a') + 1;
		rank = Integer.parseInt(square.substring(1,2));
		
		//perform extra check ?
		if (SuicideChess.SQUARE_CHECK_INVALID) {
			if (fileNb<1 || fileNb>Board.NB_OF_FILES) {
				throw new NotAValidSquare(square);
			}
			if (rank<1 || rank>Board.NB_OF_RANKS) {
				throw new NotAValidSquare(square);
			}
		}
	}
	
	/**
	 * Returns the file of a Square.
	 * @return char representing the file
	 */
	
	public char getFile() {
		return file;
	}
	
	/**
	 * Returns the number of the Rank
	 * @return int representing the rank
	 */
	public int getRank() {
		return rank;
	}
	
	/**
	 * Returns the number of the File
	 * @return int representing the file
	 */
	public int getFileNb() {
		return fileNb;
	}
	
	/**
	 * Converts a Square back to a String
	 * @return String
	 */
	public String toString() {
		return String.valueOf(file)+String.valueOf(rank);
	}
}
